@@ -27,12 +27,12 @@ class Vapi:
         self.api_key = api_key
         self.api_url = api_url
 
-    def start(self, *, assistant_id=None, assistant=None):
+    def start(self, *, assistant_id=None, assistant=None, assistant_overrides=None):
         # Start a new call
         if assistant_id:
-            assistant = {'assistantId': assistant_id}
+            assistant = {'assistantId': assistant_id, 'assistantOverrides': assistant_overrides}
         elif assistant:
-            assistant = {'assistant': assistant}
+            assistant = {'assistant': assistant, 'assistantOverrides': assistant_overrides}
 
         call_id, web_call_url = create_web_call(
             self.api_url, self.api_key, assistant)
